# Data

## PropertyDetails

Types:

```python
from mainstay.types.data import PropertyDetailsResponse
```

Methods:

- <code title="post /api/v2/data/property-details">client.data.property_details.<a href="./src/mainstay/resources/data/property_details.py">\_fetch</a>(\*\*<a href="src/mainstay/types/data/property_details_fetch_params.py">params</a>) -> <a href="./src/mainstay/types/data/property_details_response.py">PropertyDetailsResponse</a></code>

## PropertyValues

Types:

```python
from mainstay.types.data import PropertyValuesResponse
```

Methods:

- <code title="post /api/v2/data/property-values">client.data.property_values.<a href="./src/mainstay/resources/data/property_values.py">\_fetch</a>(\*\*<a href="src/mainstay/types/data/property_values_fetch_params.py">params</a>) -> <a href="./src/mainstay/types/data/property_values_response.py">PropertyValuesResponse</a></code>

## RentEstimates

Types:

```python
from mainstay.types.data import RentEstimatesResponse
```

Methods:

- <code title="post /api/v2/data/rent-estimates">client.data.rent_estimates.<a href="./src/mainstay/resources/data/rent_estimates.py">\_fetch</a>(\*\*<a href="src/mainstay/types/data/rent_estimates_fetch_params.py">params</a>) -> <a href="./src/mainstay/types/data/rent_estimates_response.py">RentEstimatesResponse</a></code>

## RentalComps

Types:

```python
from mainstay.types.data import RentalCompsResponse
```

Methods:

- <code title="post /api/v2/data/rental-comps">client.data.rental_comps.<a href="./src/mainstay/resources/data/rental_comps.py">\_fetch</a>(\*\*<a href="src/mainstay/types/data/rental_comps_fetch_params.py">params</a>) -> <a href="./src/mainstay/types/data/rental_comps_response.py">RentalCompsResponse</a></code>

## CrimeData

Types:

```python
from mainstay.types.data import CrimeDataResponse
```

Methods:

- <code title="post /api/v2/data/crime-data">client.data.crime_data.<a href="./src/mainstay/resources/data/crime_data.py">\_fetch</a>(\*\*<a href="src/mainstay/types/data/crime_data_fetch_params.py">params</a>) -> <a href="./src/mainstay/types/data/crime_data_response.py">CrimeDataResponse</a></code>

## SchoolRatings

Types:

```python
from mainstay.types.data import SchoolRatingsResponse
```

Methods:

- <code title="post /api/v2/data/school-ratings">client.data.school_ratings.<a href="./src/mainstay/resources/data/school_ratings.py">\_fetch</a>(\*\*<a href="src/mainstay/types/data/school_ratings_fetch_params.py">params</a>) -> <a href="./src/mainstay/types/data/school_ratings_response.py">SchoolRatingsResponse</a></code>
